Volumes are block devices that can be attached to instances.

Name

A volume name less than {$createVolumeCtrl.validationRules.fieldMaxLength + 1$} characters is required.

Description

A volume description less than {$createVolumeCtrl.validationRules.fieldMaxLength + 1$} characters is required.

Use image as a source
Type
Size (GiB)
Availability Zone

Volume Type Description:

{$ createVolumeCtrl.volumeType.name $}
  {$ createVolumeCtrl.volumeType.description $}